@@ -108,7 +108,7 @@ use LWP::UserAgent;
 use Scalar::Util 1.10 qw{ blessed looks_like_number };
 use XML::Parser;
 
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 
 use constant BEST_DATA_SET => -1;
 
@@ -526,9 +526,6 @@ about it.
 
 =cut
 
-my $bad_extent_re = _make_matcher(
-    q{Conversion from string "BAD_EXTENT" to type 'Double'} );
-
 sub getElevation {
     my ($self, $lat, $lon, $source, $only) = _latlon( @_ );
     defined $source or $source = BEST_DATA_SET;
@@ -716,8 +713,8 @@ sub _set_use_all_limit {
 #	error reported in the SOAP packet in lieu of the actual data
 #	(i.e. when the no SOAP error was reported).
 
-my $no_elevation_value_re = _make_matcher(
-    q{ERROR: No Elevation value was returned} );
+my $no_elevation_value_re =
+    qr{ERROR: No Elevation values? (?:was|were) returned}smi;
 
 sub _digest {
     my ($self, $rslt, $source) = @_;
@@ -946,16 +943,6 @@ sub _instance {
     }
 }
 
-sub _make_matcher {	## no critic (RequireArgUnpacking)
-    my $string = join ' ', @_;
-    $string =~ s/ [ ] / [ ] /smxg;
-    $string =~ m/ \A \w /smx
-	and substr $string, 0, 0, '\b ';
-    $string =~ m/ \w \z /smx
-	and $string .= ' \b';
-    return qr{ $string }smx;
-}
-
 {
     my %static = (	# Static attribute values.
 	throttle => 0,
@@ -1346,7 +1333,7 @@ Thomas R. Wyant, III; F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2012 Thomas R. Wyant, III
+Copyright (C) 2008-2013 Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
